From ac6c2a7d46603202be3a4f4d677f0be274d15e23 Mon Sep 17 00:00:00 2001
From: eplanet
Date: Sat, 10 Nov 2018 10:47:05 +0100
Subject: Add timezone switch

---
 man/i3status.man | 4 ++++
 1 file changed, 4 insertions(+)

(limited to 'man/i3status.man')

diff --git a/man/i3status.man b/man/i3status.man
index 7d27ae3..b3f71bf 100644
--- a/man/i3status.man
+++ b/man/i3status.man
@@ -97,6 +97,7 @@ path_exists VPN {
 
 tztime local {
         format = "%Y-%m-%d %H:%M:%S"
+        only_when_tz_different = true
 }
 
 tztime berlin {
@@ -514,6 +515,8 @@ Files below that path make for valid timezone strings, e.g. for
 +/usr/share/zoneinfo/Europe/Berlin+ you can set timezone to +Europe/Berlin+
 in the +tztime+ module.
 To override the locale settings of your environment, set the +locale+ option.
+To display time only when the timezone is different from local timezone, set
++only_when_tz_different+ to true.
 
 *Example order*: +tztime berlin+
 
@@ -533,6 +536,7 @@ tztime berlin {
 	format = "<span foreground='#ffffff'>time:</span> %time"
 	format_time = "%H:%M %Z"
 	timezone = "Europe/Berlin"
+	only_when_tz_different = false
 }
 -------------------------------------------------------------
 
-- 
cgit v1.2.3


From 1b7501b7ea561404b2dd27297a4ccd7432db46f4 Mon Sep 17 00:00:00 2001
From: eplanet
Date: Thu, 15 Nov 2018 22:27:23 +0100
Subject: Corrections according to PR review

---
 i3status.c         | 4 ++--
 include/i3status.h | 2 +-
 man/i3status.man   | 8 ++++----
 src/print_time.c   | 9 +++++----
 4 files changed, 12 insertions(+), 11 deletions(-)

(limited to 'man/i3status.man')

diff --git a/i3status.c b/i3status.c
index ea29a35..36789f4 100644
--- a/i3status.c
+++ b/i3status.c
@@ -399,7 +399,7 @@ int main(int argc, char *argv[]) {
         CFG_STR("timezone", "", CFGF_NONE),
         CFG_STR("locale", "", CFGF_NONE),
         CFG_STR("format_time", NULL, CFGF_NONE),
-        CFG_BOOL("only_when_tz_different", false, CFGF_NONE),
+        CFG_BOOL("hide_if_equals_localtime", false, CFGF_NONE),
         CFG_CUSTOM_ALIGN_OPT,
         CFG_CUSTOM_MIN_WIDTH_OPT,
         CFG_CUSTOM_SEPARATOR_OPT,
@@ -756,7 +756,7 @@ int main(int argc, char *argv[]) {
 
             CASE_SEC_TITLE("tztime") {
                 SEC_OPEN_MAP("tztime");
-                print_time(json_gen, buffer, title, cfg_getstr(sec, "format"), cfg_getstr(sec, "timezone"), cfg_getstr(sec, "locale"), cfg_getstr(sec, "format_time"), cfg_getbool(sec, "only_when_tz_different"), tv.tv_sec);
+                print_time(json_gen, buffer, title, cfg_getstr(sec, "format"), cfg_getstr(sec, "timezone"), cfg_getstr(sec, "locale"), cfg_getstr(sec, "format_time"), cfg_getbool(sec, "hide_if_equals_localtime"), tv.tv_sec);
                 SEC_CLOSE_MAP;
             }
 
diff --git a/include/i3status.h b/include/i3status.h
index e377d5b..d79ab28 100644
--- a/include/i3status.h
+++ b/include/i3status.h
@@ -214,7 +214,7 @@ const char *first_eth_interface(const net_type_t type);
 void print_ipv6_info(yajl_gen json_gen, char *buffer, const char *format_up, const char *format_down);
 void print_disk_info(yajl_gen json_gen, char *buffer, const char *path, const char *format, const char *format_below_threshold, const char *format_not_mounted, const char *prefix_type, const char *threshold_type, const double low_threshold);
 void print_battery_info(yajl_gen json_gen, char *buffer, int number, const char *path, const char *format, const char *format_down, const char *status_chr, const char *status_bat, const char *status_unk, const char *status_full, int low_threshold, char *threshold_type, bool last_full_capacity, bool integer_battery_capacity, bool hide_seconds);
-void print_time(yajl_gen json_gen, char *buffer, const char *title, const char *format, const char *tz, const char *locale, const char *format_time, bool only_when_tz_different, time_t t);
+void print_time(yajl_gen json_gen, char *buffer, const char *title, const char *format, const char *tz, const char *locale, const char *format_time, bool hide_if_equals_localtime, time_t t);
 void print_ddate(yajl_gen json_gen, char *buffer, const char *format, time_t t);
 const char *get_ip_addr(const char *interface, int family);
 void print_wireless_info(yajl_gen json_gen, char *buffer, const char *interface, const char *format_up, const char *format_down, const char *quality_min_lenght);
diff --git a/man/i3status.man b/man/i3status.man
index b3f71bf..cc363f5 100644
--- a/man/i3status.man
+++ b/man/i3status.man
@@ -97,7 +97,7 @@ path_exists VPN {
 
 tztime local {
         format = "%Y-%m-%d %H:%M:%S"
-        only_when_tz_different = true
+        hide_if_equals_localtime = true
 }
 
 tztime berlin {
@@ -515,8 +515,8 @@ Files below that path make for valid timezone strings, e.g. for
 +/usr/share/zoneinfo/Europe/Berlin+ you can set timezone to +Europe/Berlin+
 in the +tztime+ module.
 To override the locale settings of your environment, set the +locale+ option.
-To display time only when the timezone is different from local timezone, set
-+only_when_tz_different+ to true.
+To display time only when the set timezone has different time from localtime, set
++hide_if_equals_localtime+ to true.
 
 *Example order*: +tztime berlin+
 
@@ -536,7 +536,7 @@ tztime berlin {
 	format = "<span foreground='#ffffff'>time:</span> %time"
 	format_time = "%H:%M %Z"
 	timezone = "Europe/Berlin"
-	only_when_tz_different = false
+	hide_if_equals_localtime = true
 }
 -------------------------------------------------------------
 
diff --git a/src/print_time.c b/src/print_time.c
index c124e1a..864aeae 100644
--- a/src/print_time.c
+++ b/src/print_time.c
@@ -34,7 +34,7 @@ void set_timezone(const char *tz) {
     tzset();
 }
 
-void print_time(yajl_gen json_gen, char *buffer, const char *title, const char *format, const char *tz, const char *locale, const char *format_time, bool only_when_tz_different, time_t t) {
+void print_time(yajl_gen json_gen, char *buffer, const char *title, const char *format, const char *tz, const char *locale, const char *format_time, bool hide_if_equals_localtime, time_t t) {
     const char *walk;
     char *outwalk = buffer;
     struct tm local_tm, tm;
@@ -49,11 +49,11 @@ void print_time(yajl_gen json_gen, char *buffer, const char *title, const char *
     set_timezone(tz);
     localtime_r(&t, &tm);
 
     // When only_when_tz_different is true, compare local and target time to display only if different
     time_t local_t = mktime(&local_tm);
     double diff = difftime(local_t, t);
-    if (only_when_tz_different && diff == 0.0) {
-        return;
+    if (hide_if_equals_localtime && diff == 0.0) {
+        goto out;
     }
 
     if (locale != NULL) {
@@ -83,6 +83,7 @@ void print_time(yajl_gen json_gen, char *buffer, const char *title, const char *
         setlocale(LC_ALL, "");
     }
 
+out:
     *outwalk = '\0';
     OUTPUT_FULL_TEXT(buffer);
 }
@@ -49,11 +49,11 @@ void print_time(yajl_gen json_gen, char *buffer, const char *title, const char *
     localtime_r(&t, &tm);
 
-    // When only_when_tz_different is true, compare local and target time to display only if different
+    // When hide_if_equals_localtime is true, compare local and target time to display only if different
     time_t local_t = mktime(&local_tm);
     double diff = difftime(local_t, t);
-- 
cgit v1.2.3